#
# spec file for package python3-Biggus
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Biggus
Version:        0.13.0
Release:        1.5
Summary:        Virtual large arrays and lazy evaluation
License:        LGPL-3.0
Group:          Development/Languages/Python
Url:            https://github.com/SciTools/biggus
Source:         https://files.pythonhosted.org/packages/source/B/Biggus/Biggus-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-2to3
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pep8
Requires:       python3-numpy
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Virtual large arrays and lazy evaluation.

For example, we can combine multiple array data sources into a single virtual array::

    >>> first_time_series = OrthoArrayAdapter(hdf_var_a)
    >>> second_time_series = OrthoArrayAdapater(hdf_var_b)
    >>> print first_time_series.shape, second_time_series.shape
    (52000, 800, 600) (56000, 800, 600)
    >>> time_series = biggus.LinearMosaic([first_time_series, second_time_series], axis=0)
    >>> time_series
    <LinearMosaic shape=(108000, 800, 600) dtype=dtype('float32')>

*Any* biggus Array can then be indexed, independent of underlying data sources::

    >>> time_series[51999:52001, 10, 12]
    <LinearMosaic shape=(2,) dtype=dtype('float32')>

And an Array can be converted to a numpy ndarray on demand::

    >>> time_series[51999:52001, 10, 12].ndarray()
    array([ 0.72151309,  0.54654914], dtype=float32)

%prep
%setup -q -n Biggus-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# test fails on pep8 errors
# %check
# nosetests -e test_pep8

%files
%defattr(-,root,root,-)
%doc COPYING COPYING.LESSER README.rst
%{python3_sitelib}/biggus/
%{python3_sitelib}/Biggus-%{version}-py*.egg-info

%changelog
* Fri Jul  8 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.13.0:
  * Add support for all NumPy ufuncs and a few more besides (#153).
  * Add __r*__ operators (#155).
  * Fix indexing of broadcast dimension (#156).
  * Fix ArrayStack for Fortran-order arrays (#159).
  * Fix indexing of unary operations (#162).
  * Fix the handling of masked arrays for unary operations (#167).
  * Fix the ability to use binary operators on two different
    bit-length data types (#165).
  * Mimic NumPy's special type-promotion behaviour when dealing with
    Python floats & ints (#169).
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Oct 31 2015 arun@gmx.de
- update to version 0.12.0:
  * A fix for the __getitem__ for LinearMosaic that corrects array
    slicing output (#147).
  * Biggus' __div__ method properly accounts for the dtype of arguments
    passed to it (#149).
  * Added support for Python 3.5 (#150).
* Fri Jun  5 2015 arun@gmx.de
- update to version 0.11.0:
  * Fix to ndarray indexing on LinearMosaic (#144)
  * Support for dtype promotion on elementwise operations (#145)
  * Addition of __orthogonal_indexing__ protocol (#142)
  * Addition of the astype array method and associated AsDataTypeArray
    object (#141)
  * Improved str and repr representations of arrays (#139)
* Fri Apr 10 2015 toddrme2178@gmail.com
- Update to version 0.10.0
  * No upstream changelog
* Thu Apr  9 2015 toddrme2178@gmail.com
- Initial python 3 version
* Thu Apr  9 2015 toddrme2178@gmail.com
- Update to version 0.8.0
  * No upstream changelog
* Fri May 30 2014 toddrme2178@gmail.com
- initial version
